pub struct LruCache<K, V> { /* private fields */ }Available on crate feature
collections only.Expand description
A cache with a maximum capacity that evicts the least recently used items.
This implementation uses a Vec for order tracking, giving O(N) access
and insertion cost per operation. It is designed for small-capacity caches
(up to ~100 entries). For high-throughput or large-capacity use cases,
consider the lru crate which provides
O(1) operations via a doubly-linked list and HashMap.
Implementations