macro_rules! logger {
() => { ... };
}Available on crate feature
logging only.Expand description
Create a logger for the current module.
Returns a Logger whose module name is set to the caller’s
module_path!(). This is the recommended way to obtain a logger
without hard-coding module strings.